@@ -219,6 +219,7 @@ class CloudRunJob(Infrastructure):
     _block_type_name = "GCP Cloud Run Job"
     _description = "Infrastructure block used to run GCP Cloud Run Jobs. Note this block is experimental. The interface may change without notice."  # noqa
     _logo_url = "https://images.ctfassets.net/gm98wzqotmnx/4CD4wwbiIKPkZDt4U3TEuW/c112fe85653da054b6d5334ef662bec4/gcp.png?h=250"  # noqa
+    _documentation_url = "https://prefecthq.github.io/prefect-gcp/cloud_run/#prefect_gcp.cloud_run.CloudRunJob"  # noqa: E501
 
     type: Literal["cloud-run-job"] = Field(
         "cloud-run-job", description="The slug for this task type."
@@ -259,6 +260,11 @@ class CloudRunJob(Infrastructure):
             "for additional details."
         ),
     )
+    vpc_connector_name: Optional[str] = Field(
+        default=None,
+        title="VPC Connector Name",
+        description="The name of the VPC connector to use for the Cloud Run Job.",
+    )
     args: Optional[List[str]] = Field(
         default=None,
         description=(
@@ -565,9 +571,13 @@ class CloudRunJob(Infrastructure):
             "name": self.job_name,
             "annotations": {
                 # See: https://cloud.google.com/run/docs/troubleshooting#launch-stage-validation  # noqa
-                "run.googleapis.com/launch-stage": "BETA"
+                "run.googleapis.com/launch-stage": "BETA",
             },
         }
+        if self.vpc_connector_name:
+            jobs_metadata["annotations"][
+                "run.googleapis.com/vpc-access-connector"
+            ] = self.vpc_connector_name
 
         # env and command here
         containers = [self._add_container_settings({"image": self.image})]
