@@ -488,6 +488,7 @@ class GcsBucket(WritableDeploymentStorage, WritableFileSystem, ObjectStorageBloc
 
     _logo_url = "https://images.ctfassets.net/gm98wzqotmnx/4CD4wwbiIKPkZDt4U3TEuW/c112fe85653da054b6d5334ef662bec4/gcp.png?h=250"  # noqa
     _block_type_name = "GCS Bucket"
+    _documentation_url = "https://prefecthq.github.io/prefect-gcp/cloud_storage/#prefect_gcp.cloud_storage.GcsBucket"  # noqa: E501
 
     bucket: str = Field(..., description="Name of the bucket.")
     gcp_credentials: GcpCredentials = Field(
@@ -529,6 +530,10 @@ class GcsBucket(WritableDeploymentStorage, WritableFileSystem, ObjectStorageBloc
         path = (
             str(PurePosixPath(self.bucket_folder, path)) if self.bucket_folder else path
         )
+        if path == "." or path == "/":
+            # client.bucket.list_blobs(prefix=None) is the proper way
+            # of specifying the root folder of the bucket
+            path = None
         return path
 
     @sync_compatible
@@ -688,7 +693,13 @@ class GcsBucket(WritableDeploymentStorage, WritableFileSystem, ObjectStorageBloc
                 f"Bucket path {bucket_path!r} is already prefixed with "
                 f"bucket folder {self.bucket_folder!r}; is this intentional?"
             )
-        return str(PurePosixPath(self.bucket_folder) / bucket_path)
+
+        bucket_path = str(PurePosixPath(self.bucket_folder) / bucket_path)
+        if bucket_path == "." or bucket_path == "/":
+            # client.bucket.list_blobs(prefix=None) is the proper way
+            # of specifying the root folder of the bucket
+            bucket_path = None
+        return bucket_path
 
     @sync_compatible
     async def get_bucket(self) -> "Bucket":
@@ -744,6 +755,46 @@ class GcsBucket(WritableDeploymentStorage, WritableFileSystem, ObjectStorageBloc
         # Ignore folders
         return [blob for blob in blobs if not blob.name.endswith("/")]
 
+    @sync_compatible
+    async def list_folders(self, folder: str = "") -> List[str]:
+        """
+        Lists all folders and subfolders in the bucket.
+
+        Args:
+            folder: List all folders and subfolders inside given folder.
+
+        Returns:
+            A list of folders.
+
+        Examples:
+            Get all folders from a bucket named "my-bucket".
+            ```python
+            from prefect_gcp.cloud_storage import GcsBucket
+
+            gcs_bucket = GcsBucket.load("my-bucket")
+            gcs_bucket.list_folders()
+            ```
+
+            Get all folders from a folder called years
+            ```python
+            from prefect_gcp.cloud_storage import GcsBucket
+
+            gcs_bucket = GcsBucket.load("my-bucket")
+            gcs_bucket.list_folders('years)
+            ```
+        """
+
+        bucket_path = self._join_bucket_folder()
+        self.logger.info(f"Listing folders in bucket {bucket_path}.")
+
+        blobs = await self.list_blobs(folder)
+        # gets all folders with full path
+        folders = {
+            str(PurePosixPath(blob.name).parent).replace(".", "") for blob in blobs
+        }
+
+        return list(folders)
+
     @sync_compatible
     async def download_object_to_path(
         self,
@@ -1049,7 +1100,10 @@ class GcsBucket(WritableDeploymentStorage, WritableFileSystem, ObjectStorageBloc
             ```
         """
         from_folder = Path(from_folder)
-        bucket_folder = self._join_bucket_folder(to_folder or "")
+        # join bucket folder expects string for the first input
+        # when it returns None, we need to convert it back to empty string
+        # so relative_to works
+        bucket_folder = self._join_bucket_folder(to_folder or "") or ""
 
         num_uploaded = 0
         bucket = await self.get_bucket()
